searchData={"content_type":"text/markdown","items":[{"doc":"OpentelemetryPhoenix uses [telemetry](https://hexdocs.pm/telemetry/) handlers to create `OpenTelemetry` spans.\n\nCurrent events which are supported include endpoint start/stop, router start/stop,\nand router exceptions.\n\n#","ref":"OpentelemetryPhoenix.html","title":"OpentelemetryPhoenix","type":"module"},{"doc":"* `:endpoint_prefix` (list of `t:atom/0`) - The endpoint prefix in your endpoint. The default value is `[:phoenix, :endpoint]`.\n\n* `:adapter` - The phoenix server adapter being used. The default value is `nil`.\n\n* `:liveview` (`t:boolean/0`) - Whether LiveView traces will be instrumented. The default value is `true`.\n\n\n\nIf you are using PlugCowboy as your adapter you can add `:opentelemetry_cowboy` to your project\nand pass the `:adapter` option when calling setup. Setting this option will prevent a new\nspan from being started and the existing cowboy span to be continued. This is the recommended\nsetup for measuring accurate latencies.\n\n`Bandit.PhoenixAdapter` is not currently supported.","ref":"OpentelemetryPhoenix.html#module-supported-options","title":"Supported options - OpentelemetryPhoenix","type":"module"},{"doc":"In your application start:\n\n    def start(_type, _args) do\n      :opentelemetry_cowboy.setup()\n      OpentelemetryPhoenix.setup(adapter: :cowboy2)\n\n      children = [\n        {Phoenix.PubSub, name: MyApp.PubSub},\n        MyAppWeb.Endpoint\n      ]\n\n      opts = [strategy: :one_for_one, name: MyStore.Supervisor]\n      Supervisor.start_link(children, opts)\n    end","ref":"OpentelemetryPhoenix.html#module-usage","title":"Usage - OpentelemetryPhoenix","type":"module"},{"doc":"","ref":"OpentelemetryPhoenix.html#attach_liveview_handlers/0","title":"OpentelemetryPhoenix.attach_liveview_handlers/0","type":"function"},{"doc":"","ref":"OpentelemetryPhoenix.html#handle_liveview_event/4","title":"OpentelemetryPhoenix.handle_liveview_event/4","type":"function"},{"doc":"Initializes and configures the telemetry handlers.","ref":"OpentelemetryPhoenix.html#setup/1","title":"OpentelemetryPhoenix.setup/1","type":"function"},{"doc":"The phoenix server adapter being used. Optional","ref":"OpentelemetryPhoenix.html#t:adapter/0","title":"OpentelemetryPhoenix.adapter/0","type":"type"},{"doc":"The endpoint prefix in your endpoint. Defaults to `[:phoenix, :endpoint]`","ref":"OpentelemetryPhoenix.html#t:endpoint_prefix/0","title":"OpentelemetryPhoenix.endpoint_prefix/0","type":"type"},{"doc":"Setup options","ref":"OpentelemetryPhoenix.html#t:opts/0","title":"OpentelemetryPhoenix.opts/0","type":"type"},{"doc":"","ref":"OpentelemetryPhoenix.Reason.html","title":"OpentelemetryPhoenix.Reason","type":"module"},{"doc":"","ref":"OpentelemetryPhoenix.Reason.html#normalize/1","title":"OpentelemetryPhoenix.Reason.normalize/1","type":"function"},{"doc":"","ref":"OpentelemetryPhoenix.Reason.html#normalize/2","title":"OpentelemetryPhoenix.Reason.normalize/2","type":"function"},{"doc":"# OpentelemetryPhoenix\n\n[![EEF Observability WG project](https://img.shields.io/badge/EEF-Observability-black)](https://github.com/erlef/eef-observability-wg)\n[![Hex.pm](https://img.shields.io/hexpm/v/opentelemetry_phoenix)](https://hex.pm/packages/opentelemetry_phoenix)\n![Build Status](https://github.com/opentelemetry-beam/opentelemetry_phoenix/workflows/Tests/badge.svg)\n\nTelemetry handler that creates Opentelemetry spans from Phoenix events.\n\nAfter installing, setup the handler in your application behaviour before your\ntop-level supervisor starts.\n\n```elixir\nOpentelemetryPhoenix.setup()\n```\n\nSee the documentation for `OpentelemetryPhoenix.setup/1` for additional options that\nmay be supplied.","ref":"readme.html","title":"OpentelemetryPhoenix","type":"extras"},{"doc":"```elixir\ndef deps do\n  [\n    {:opentelemetry_phoenix, \"~> 1.2\"}\n  ]\nend\n```\n\nIt is high recommended to also install [OpentelemetryCowboy](https://hex.pm/packages/opentelemetry_cowboy) to capture the full\nrequest lifecycle. Phoenix only handles part of the request lifecycle which can lead\nto incomplete request durations and lost traces for requests terminated at the socket\nlevel or before reaching Phoenix.","ref":"readme.html#installation","title":"Installation - OpentelemetryPhoenix","type":"extras"},{"doc":"| OpentelemetryPhoenix Version | Otel Version | Notes |\n| :--------------------------- | :----------- | :---- |\n|                              |              |       |\n| v0.1.0                       | <= v.0.5.0   |       |\n| v1.0.0-rc.3                  | v1.0.0-rc.1  |       |\n|                              | v1.0.0-rc.2  |       |\n| v1.0.0-rc.4                  | v1.0.0-rc.2  | Otel rc.3 will be a breaking change |\n| v1.0.0-rc.5                  | v1.0.0-rc.3  |       |\n| v1.0.0-rc.6                  | v1.0.0-rc.4  |       |\n| v1.0                         | v1.0         |       |","ref":"readme.html#compatibility-matrix","title":"Compatibility Matrix - OpentelemetryPhoenix","type":"extras"},{"doc":"`OpentelemetryPhoenix` requires phoenix to use `Plug.Telemetry` in order to correctly trace endpoint calls.\n\nThe `endpoint.ex` file should look like:\n```Elixir\ndefmodule MyApp.Endpoint do\n  use Phoenix.Endpoint, otp_app: :my_app\n  ...\n  plug Plug.Telemetry, event_prefix: [:phoenix, :endpoint]\n  ...\nend\n```\nThe [Phoenix endpoint.ex template](https://github.com/phoenixframework/phoenix/blob/v1.6.0/installer/templates/phx_web/endpoint.ex#L39) can be used as a reference","ref":"readme.html#note-on-phoenix-integration","title":"Note on phoenix integration - OpentelemetryPhoenix","type":"extras"}]}